#
# spec file for package libretro-parallel-n64
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libretro-parallel-n64
Version:        0~git20201011
Release:        bp153.1.1
Summary:        Parallel N64 libretro core for Nintendo 64 emulation
License:        GPL-3.0-only
Group:          System/Emulators/Other
URL:            http://www.retroarch.com
Source:         %{name}-%{version}.tar.xz

BuildRequires:  Mesa-devel
BuildRequires:  gcc-c++
BuildRequires:  make

ExcludeArch:    armv6l armv6hl

%description
Optimized/rewritten Nintendo 64 emulator made specifically for Libretro.
Originally based on Mupen64 Plus.

%prep
%setup -q

%build
sed -i "s#aarch64-linux-gnu-##" Makefile
# https://github.com/libretro/libretro-super/blob/master/recipes/linux
%ifarch x86_64
    make WITH_DYNAREC=x86_64 HAVE_PARALLEL_RSP=1 HAVE_THR_AL=1
%endif
%ifarch %ix86
    make WITH_DYNAREC=x86 HAVE_PARALLEL_RSP=1 HAVE_THR_AL=1
%endif
%ifarch %arm
    make WITH_DYNAREC=arm HAVE_THR_AL=1 platform=classic_armv7_a7
%endif
%ifarch aarch64
    make WITH_DYNAREC=aarch64 HAVE_THR_AL=1 platform=armv8
%endif

%install
mkdir -p %{buildroot}%{_libdir}/libretro
cp parallel_n64_libretro.so %{buildroot}%{_libdir}/libretro

%files
%dir %{_libdir}/libretro
%{_libdir}/libretro/parallel_n64_libretro.so

%changelog
* Thu Oct 15 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix aarch64 and armv7 builds
- Disable armv6 builds
* Thu Oct 15 2020 guillaume.gardet@opensuse.org
- Update to version 0~git20201011:
  * Fix Makefile
  * Add .gitlab-ci.yml
  * Xcode wants his cariables initialized or won't link externs
  * Fix GCC10 compilation (-fno-common fixes)
  * Solve armv & armv8 compilation
  * Use all possible optimizations.
  * Fix dithering in AL+.
  * Fix spurious RSP crashes.
  * Update paraLLEl-RDP.
  * Make proper note of texture filtering.
  * Update parallel-rdp.
  * Update parallel-RDP.
  * Add more crop pixel options
  * Update paraLLEl-RDP.
  * Implement logging levels
  * Update parallel-RDP.
  * Update paraLLEl-RDP.
  * Use same types as mesa and new headers shipped with gpu blobs.
* Sun Jun  7 2020 i@guoyunhe.me
- Add aarch64 build
- Update to version 0~git20200529:
  * Update parallel-RDP.
  * Update Android.mk
  * Update Android.mk
  * Add missing files.
  * Update parallel-RDP.
  * Update parallel-RDP.
  * Update Android Application.mk
  * Add README explaining how to dump.
  * Update parallel-rdp.
  * switch video driver according to gfx plugin
  * Add amalgamated parallel-rdp build.
  * Move to new paraLLEl-RDP.
  * Add SI DMA Duration hack for Tetris 64
  * Use separate cache for DRAM and hidden DRAM.
  * Dump the hidden RDRAM as well.
  * Add DRAM flush and fix VI_REGISTER_OUTPUT.
  * Move RDP_DUMP over to Angrylion.
  * Fix Seg Fault on Game Unload
  * Makefile cleanups
  * Revert "Backport https://github.com/ata4/angrylion-rdp-plus/commit/de4fe4f0ed4d849651639088c0dc36fcba70b8cc"
  * Backport https://github.com/ata4/angrylion-rdp-plus/commit/de4fe4f0ed4d849651639088c0dc36fcba70b8cc
  * Not necessary to set Quake 2 to Count Per Op 1
  * Remove .d files
  * Revert "Updates"
  * Updates
  * Set this to 1
  * Get rid of -lversion now, no longer using LLVM
  * Bake out Parallel RDP for Android right now
* Mon Feb 10 2020 i@guoyunhe.me
- Update to version 0~git20200210:
  * Added -DARM_FIX for rpi and odroid CPUFLAGS - fixes #544
  * (Android) Take out x86/x64 for now - add Parallel RSP
  * Update Application.mk
  * Attempt to fix compilation on buildbot
  * Buildfix
  * git subrepo pull mupen64plus-rsp-paraLLEl
  * Remove this - was never used + potential license issues
  * git subrepo pull mupen64plus-rsp-paraLLEl
  * git subrepo pull mupen64plus-rsp-paraLLEl
  * git subrepo clone https://github.com/Themaister/parallel-rsp.git mupen64plus-rsp-paraLLEl
  * Update Makefile for new parallel-rsp module.
  * Remove old parallel-rsp implementation.
  * Add Xena entries to CountPerOp=3
  * Remove CountPerOp=1 for Star Wars Episode 1 Racer
  * AL option to select number of threads
  * Actually flip or dupe when using AL+ when needed.
  * Change this too
  * Thread sync level - set low as default
  * Link in LLVM statically
  * Link llvm in statically
  * Add way to override LLVM
  * parallel-RSP: Port over MFC0 timeout and some semaphore handling code.
  * angrylion unfiltered width temp fix
  * OSX Buildfix
  * (Parallel N64) Add -lpthread
  * VI overlay, more options.
  * Backport https://github.com/mupen64plus/mupen64plus-core/pull/533 - setting Vigilante 8 games to CountPerOp 1 was apparently a bad idea, performance greatly increased with default framerate setting
  * Backport https://github.com/mupen64plus/mupen64plus-core/pull/544/commits/03e16a93d773801f05715db9e0356374754746b7
  * Update
  * (Angrylion) interface.cpp was already C, so turn it into that - parallel_al.cpp remains the only C++ file
  * We use MSB_FIRST instead of LSB_FIRST
  * (Angrylion) remove unused functions
  * (Angrylion) remove unused screen.c
  * (Angrylion) Refactor setting dithering
  * (Angrylion) Remove unused GL-specific vdac.c code
  * video-angrylion: Make cache line striding a define.
  * video-angrylion: Don't false share cachelines.
  * video-angrylion: Move assign the task lambda.
  * video-angrylion: Hack in an environment variable to tweak thread count.
  * video-angrylion: Fix parallel thread scheduler for 64 threads.
  * Resampler - update - should bring this in line with libretro-common repo later
  * Update Makefile
  * (Angrylion) Get rid of intermediate framebuffer copying
  * parallel-RSP: Use __builtin_setjmp/longjmp.
  * parallel-RSP: Fix linking order for Clang.
  * Fix parallel-RSP build against modern LLVM.
  * Change to a sane thread synchronization level.
  * Fixed threading for sure. For best results turn down the thread sync.
  * (Angrylion) C89/C90 buildfix
  * Update
  * Updates
  * Add HAVE_THR_AL ifdefs
  * (MSVC 2017) Buildfix
  * Update interface.cpp
  * Update.
  * Added support for frontends not supporting GET_PREFERRED_HW_RENDER.
  * fix byte order for libretro.
  * now initializes, but runs slow.
  * the api changed a fair bit, now need to specify rdram ptrs.
  * fix typo.
  * Add option for thread sync level. Useful for games that need to sync to framebuffer commands, such as CBFD.
  * Update to newest Angrylion (WIP)
  * Properly negotiating driver to use with frontend.
  * allow compile for ios-arm64
* Tue Oct  8 2019 i@guoyunhe.me
- Update to version 0~git20190917:
  * Update .travis.yml
  * Added Classic Travis
  * Update Makefile
  * Fix PSClassic config
  * Fix musl build, stderr is in stdio.h
  * makefile cleanup
  * Fix build with clang.
  * Implement subsystems for cart+disk loading
* Tue Oct  8 2019 Yunhe Guo <i@guoyunhe.me>
- First version
